@@ -45,6 +45,11 @@ class CustomAttributeResource(InstanceResource):
                 'version': version
             }
         )
+        cache_key = self.requester.get_full_url(
+            '/{endpoint}/custom-attributes-values/{id}',
+            endpoint=self.endpoint, id=self.id
+        )
+        self.requester.cache.put(cache_key, response)
         return response.json()
 
     def _get_attributes(self, cache=False):
